@@ -12,18 +12,11 @@ from git_code_debt.repo_parser import Commit
 
 class MetricInfo(NamedTuple):
     name: str
-    description: str
+    description: str = ''
 
-
-MetricInfo.__new__.__defaults__ = ('',)
-
-
-@classmethod
-def from_class(cls, c: 'Type[DiffParserBase]') -> 'MetricInfo':
-    return cls(c.__name__, inspect.cleandoc(c.__doc__ or ''))
-
-
-MetricInfo.from_class = from_class
+    @classmethod
+    def from_class(cls, c: 'Type[DiffParserBase]') -> 'MetricInfo':
+        return cls(c.__name__, inspect.cleandoc(c.__doc__ or ''))
 
 
 class DiffParserBase:
